@@ -4,7 +4,7 @@
 # @title "Gets a unique non-existing temporary variable name"
 #
 # \description{
-#  @get "title" and optionally assigns it an initial value.
+#  @get "title", and optionally assigns it an initial value.
 # }
 #
 # @synopsis
@@ -13,8 +13,10 @@
 #   \item{prefix}{A @character string specifying the prefix of the
 #     temporary variable name.}
 #   \item{value}{(optional) If given, a variable with the temporary
-#     name is assigned this value.}
-#   \item{envir}{An @environment where the variable should exist.}
+#     name is assigned this value.  Only works if \code{envir} is an
+#     environment.}
+#   \item{envir}{An @environment, a named @list, or a named @data.frame,
+#     whose elements the temporary variable should not clash with.}
 #   \item{inherits}{A @logical specifying whether the enclosing frames
 #     of the environment should be searched or not.}
 # }
@@ -38,6 +40,17 @@ tempvar <- function(prefix="var", value, envir=parent.frame(), inherits=FALSE) {
   maxTries <- 1e6
   maxInt <- .Machine$integer.max
 
+  isEnv <- is.environment(envir)
+  if (!isEnv) {
+    names <- names(envir)
+    if (is.null(names)) {
+      stop("Argument 'envir' specifies an object without names attributes: ", mode(envir))
+    }
+    if (!missing(value)) {
+      stop("Can only assign a value to a temporary variables in an environment: ", mode(envir))
+    }
+  }
+
   ii <- 0L
   while (ii < maxTries) {
     # Generate random variable name
@@ -45,12 +58,18 @@ tempvar <- function(prefix="var", value, envir=parent.frame(), inherits=FALSE) {
     name <- sprintf("%s%d", prefix, idx)
 
     # Is it available?
-    if (!exists(name, envir=envir, inherits=inherits)) {
-      # Assign a value?
-      if (!missing(value)) {
-        assign(name, value, envir=envir, inherits=inherits)
+    if (isEnv) {
+      if (!exists(name, envir=envir, inherits=inherits)) {
+        # Assign a value?
+        if (!missing(value)) {
+          assign(name, value, envir=envir, inherits=inherits)
+        }
+        return(name)
+      }
+    } else {
+      if (!is.element(name, names)) {
+        return(name)
       }
-      return(name)
     }
 
     # Next try
